@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 Functions to manage a template and wheter it should be stored in S3
@@ -9,6 +8,7 @@ import pprint
 from os.path import abspath
 
 import yaml
+from retry import retry
 
 try:
     from yaml import CDumper as Dumper
@@ -66,7 +66,32 @@ def upload_file(
     return f"https://s3.amazonaws.com/{bucket_name}/{key}"
 
 
-class FileArtifact(object):
+class RetryThis(Exception):
+    pass
+
+
+@retry(RetryThis, tries=2, delay=5)
+def validate_wrapper(session, body: str = None, url: str = None):
+    """
+
+    :param session:
+    :param body:
+    :param url:
+    :return:
+    """
+    client = session.client("cloudformation")
+    try:
+        if url:
+            client.validate_template(TemplateURL=url)
+        elif body:
+            client.validate_template(TemplateBody=body)
+    except ClientError as error:
+        if error.response["Error"]["Code"] == "Throttling":
+            raise RetryThis(error)
+        raise
+
+
+class FileArtifact:
     """
     Class to handle files artifacts, such as configuration files or templates.
     It will allow to upload the content to S3 or write to local filesystem.
@@ -169,9 +194,7 @@ class FileArtifact(object):
         """
         try:
             if not settings.no_upload and self.url:
-                settings.session.client("cloudformation").validate_template(
-                    TemplateURL=self.url
-                )
+                validate_wrapper(settings.session, url=self.url)
             elif settings.no_upload or not self.url:
                 if not self.file_path:
                     self.write(settings)
@@ -182,9 +205,7 @@ class FileArtifact(object):
                         " No upload is True, so skipping."
                     )
                 else:
-                    settings.session.client("cloudformation").validate_template(
-                        TemplateBody=self.body
-                    )
+                    validate_wrapper(settings.session, body=self.body)
             LOG.debug(f"Template {self.file_name} was validated successfully by CFN")
         except ClientError as error:
             LOG.error(error)
