@@ -1,6 +1,5 @@
-#  -*- coding: utf-8 -*-
 # SPDX-License-Identifier: MPL-2.0
-# Copyright 2020-2021 John Mille <john@compose-x.io>
+# Copyright 2020-2022 John Mille <john@compose-x.io>
 
 """
 From the docker ComposeX definition file, allows to add generic tags to all objects supporting AWS Tags from CFN
@@ -28,6 +27,7 @@ from troposphere import Ref, Tags
 from troposphere.ec2 import LaunchTemplate, TagSpecifications
 from troposphere.ssm import Parameter as SSMParameter
 
+from ecs_composex import __version__ as version
 from ecs_composex.common import LOG, NONALPHANUM, add_parameters
 from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.common.stacks import ComposeXStack
@@ -82,6 +82,7 @@ def generate_tags_parameters(tags):
                 define_tag_parameter_title(tag["Key"])
                 if isinstance(tags, list)
                 else define_tag_parameter_title(tag),
+                group_label="Tagging",
                 Type="String",
                 MinLength=2,
                 MaxLength=128,
@@ -147,7 +148,7 @@ def add_object_tags(obj, tags):
     elif isinstance(obj, excluded_types):
         return
     if hasattr(obj, "props") and "Tags" not in obj.props:
-        LOG.debug(f"Item {obj.title} - {obj.resource_type} does not support tags")
+        LOG.debug(f"Item {obj} does not support tags")
         return
     if hasattr(obj, "Tags") and isinstance(getattr(obj, "Tags"), Tags):
         LOG.debug(f"Adding the new tags {clean_tags} to {obj}")
@@ -163,7 +164,12 @@ def add_object_tags(obj, tags):
 
 
 def default_tags():
-    return Tags(CreatedByComposeX=True)
+    """
+    Function to return default tags to set on resource
+    :return: default compose-x tags
+    :rtype: troposphere.Tags
+    """
+    return Tags(CreatedByComposeX=True, **{"compose-x::version": version})
 
 
 def apply_tags_to_resources(settings, resource, params, xtags):
@@ -187,8 +193,8 @@ def apply_tags_to_resources(settings, resource, params, xtags):
             or not resource.stack_template
         ):
             return
-        for stack_resname in resource.stack_template.resources:
-            add_object_tags(resource.stack_template.resources[stack_resname], xtags)
+        for stack_resource in resource.stack_template.resources.values():
+            add_object_tags(stack_resource, xtags)
 
 
 def add_all_tags(root_template, settings, params=None, xtags=None):
