@@ -50,6 +50,7 @@ from ecs_composex.ecs.ecs_conditions import (
     USE_WINDOWS_OS_T,
 )
 
+from .helpers import extend_container_envvars
 from .service_image import ServiceImage
 
 
@@ -159,6 +160,8 @@ class ComposeService:
         map_volumes(self, volumes)
         map_secrets(self, secrets)
         self.set_container_definition()
+        self.links = set_else_none("links", definition)
+        self.family_links: list = []
 
     def __repr__(self):
         return self.name
@@ -927,6 +930,9 @@ class ComposeService:
             else self.ecs_user,
         )
 
+        _to_add = [secret.env_var for secret in self.secrets]
+        extend_container_envvars(self.container_definition, _to_add)
+
     def set_user_group(self):
         """
         Method to assign the user / group IDs for the container
